@@ -18,7 +18,7 @@ class MagicData(Filter):
 
     async def __call__(self, event: TelegramObject, *args: Any, **kwargs: Any) -> Any:
         return self.magic_data.resolve(
-            AttrDict({"event": event, **dict(enumerate(args)), **kwargs})
+            AttrDict({"event": event, **dict(enumerate(args)), **kwargs}),
         )
 
     def __str__(self) -> str:
