@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Optional, Union
+from typing import TYPE_CHECKING, Any
 
 from pydantic import Field
 
@@ -23,30 +23,28 @@ class SendMediaGroup(TelegramMethod[list[Message]]):
     """Unique identifier for the target chat or username of the target channel (in the format :code:`@channelusername`)"""
     media: list[MediaUnion]
     """A JSON-serialized array describing messages to be sent, must include 2-10 items"""
-    business_connection_id: Optional[str] = None
+    business_connection_id: str | None = None
     """Unique identifier of the business connection on behalf of which the message will be sent"""
-    message_thread_id: Optional[int] = None
-    """Unique identifier for the target message thread (topic) of the forum; for forum supergroups only"""
-    direct_messages_topic_id: Optional[int] = None
+    message_thread_id: int | None = None
+    """Unique identifier for the target message thread (topic) of a forum; for forum supergroups and private chats of bots with forum topic mode enabled only"""
+    direct_messages_topic_id: int | None = None
     """Identifier of the direct messages topic to which the messages will be sent; required if the messages are sent to a direct messages chat"""
-    disable_notification: Optional[bool] = None
+    disable_notification: bool | None = None
     """Sends messages `silently <https://telegram.org/blog/channels-2-0#silent-messages>`_. Users will receive a notification with no sound."""
-    protect_content: Optional[Union[bool, Default]] = Default("protect_content")
+    protect_content: bool | Default | None = Default("protect_content")
     """Protects the contents of the sent messages from forwarding and saving"""
-    allow_paid_broadcast: Optional[bool] = None
+    allow_paid_broadcast: bool | None = None
     """Pass :code:`True` to allow up to 1000 messages per second, ignoring `broadcasting limits <https://core.telegram.org/bots/faq#how-can-i-message-all-of-my-bot-39s-subscribers-at-once>`_ for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot's balance"""
-    message_effect_id: Optional[str] = None
+    message_effect_id: str | None = None
     """Unique identifier of the message effect to be added to the message; for private chats only"""
-    reply_parameters: Optional[ReplyParameters] = None
+    reply_parameters: ReplyParameters | None = None
     """Description of the message to reply to"""
-    allow_sending_without_reply: Optional[bool] = Field(
-        None, json_schema_extra={"deprecated": True}
-    )
+    allow_sending_without_reply: bool | None = Field(None, json_schema_extra={"deprecated": True})
     """Pass :code:`True` if the message should be sent even if the specified replied-to message is not found
 
 .. deprecated:: API:7.0
    https://core.telegram.org/bots/api-changelog#december-29-2023"""
-    reply_to_message_id: Optional[int] = Field(None, json_schema_extra={"deprecated": True})
+    reply_to_message_id: int | None = Field(None, json_schema_extra={"deprecated": True})
     """If the messages are a reply, ID of the original message
 
 .. deprecated:: API:7.0
@@ -61,16 +59,16 @@ class SendMediaGroup(TelegramMethod[list[Message]]):
             *,
             chat_id: ChatIdUnion,
             media: list[MediaUnion],
-            business_connection_id: Optional[str] = None,
-            message_thread_id: Optional[int] = None,
-            direct_messages_topic_id: Optional[int] = None,
-            disable_notification: Optional[bool] = None,
-            protect_content: Optional[Union[bool, Default]] = Default("protect_content"),
-            allow_paid_broadcast: Optional[bool] = None,
-            message_effect_id: Optional[str] = None,
-            reply_parameters: Optional[ReplyParameters] = None,
-            allow_sending_without_reply: Optional[bool] = None,
-            reply_to_message_id: Optional[int] = None,
+            business_connection_id: str | None = None,
+            message_thread_id: int | None = None,
+            direct_messages_topic_id: int | None = None,
+            disable_notification: bool | None = None,
+            protect_content: bool | Default | None = Default("protect_content"),
+            allow_paid_broadcast: bool | None = None,
+            message_effect_id: str | None = None,
+            reply_parameters: ReplyParameters | None = None,
+            allow_sending_without_reply: bool | None = None,
+            reply_to_message_id: int | None = None,
             **__pydantic_kwargs: Any,
         ) -> None:
             # DO NOT EDIT MANUALLY!!!
