@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Optional
+from typing import TYPE_CHECKING, Any
 
 from ..types import InputFile
 from .base import TelegramMethod
@@ -28,17 +28,17 @@ class SetWebhook(TelegramMethod[bool]):
 
     url: str
     """HTTPS URL to send updates to. Use an empty string to remove webhook integration"""
-    certificate: Optional[InputFile] = None
+    certificate: InputFile | None = None
     """Upload your public key certificate so that the root certificate in use can be checked. See our `self-signed guide <https://core.telegram.org/bots/self-signed>`_ for details."""
-    ip_address: Optional[str] = None
+    ip_address: str | None = None
     """The fixed IP address which will be used to send webhook requests instead of the IP address resolved through DNS"""
-    max_connections: Optional[int] = None
+    max_connections: int | None = None
     """The maximum allowed number of simultaneous HTTPS connections to the webhook for update delivery, 1-100. Defaults to *40*. Use lower values to limit the load on your bot's server, and higher values to increase your bot's throughput."""
-    allowed_updates: Optional[list[str]] = None
+    allowed_updates: list[str] | None = None
     """A JSON-serialized list of the update types you want your bot to receive. For example, specify :code:`["message", "edited_channel_post", "callback_query"]` to only receive updates of these types. See :class:`aiogram.types.update.Update` for a complete list of available update types. Specify an empty list to receive all update types except *chat_member*, *message_reaction*, and *message_reaction_count* (default). If not specified, the previous setting will be used."""
-    drop_pending_updates: Optional[bool] = None
+    drop_pending_updates: bool | None = None
     """Pass :code:`True` to drop all pending updates"""
-    secret_token: Optional[str] = None
+    secret_token: str | None = None
     """A secret token to be sent in a header 'X-Telegram-Bot-Api-Secret-Token' in every webhook request, 1-256 characters. Only characters :code:`A-Z`, :code:`a-z`, :code:`0-9`, :code:`_` and :code:`-` are allowed. The header is useful to ensure that the request comes from a webhook set by you."""
 
     if TYPE_CHECKING:
@@ -49,12 +49,12 @@ class SetWebhook(TelegramMethod[bool]):
             __pydantic__self__,
             *,
             url: str,
-            certificate: Optional[InputFile] = None,
-            ip_address: Optional[str] = None,
-            max_connections: Optional[int] = None,
-            allowed_updates: Optional[list[str]] = None,
-            drop_pending_updates: Optional[bool] = None,
-            secret_token: Optional[str] = None,
+            certificate: InputFile | None = None,
+            ip_address: str | None = None,
+            max_connections: int | None = None,
+            allowed_updates: list[str] | None = None,
+            drop_pending_updates: bool | None = None,
+            secret_token: str | None = None,
             **__pydantic_kwargs: Any,
         ) -> None:
             # DO NOT EDIT MANUALLY!!!
