@@ -16,14 +16,17 @@ if TYPE_CHECKING:
 
 class KeyboardButton(MutableTelegramObject):
     """
-    This object represents one button of the reply keyboard. At most one of the optional fields must be used to specify type of the button. For simple text buttons, *String* can be used instead of this object to specify the button text.
-    **Note:** *request_users* and *request_chat* options will only work in Telegram versions released after 3 February, 2023. Older clients will display *unsupported message*.
+    This object represents one button of the reply keyboard. At most one of the fields other than *text*, *icon_custom_emoji_id*, and *style* must be used to specify the type of the button. For simple text buttons, *String* can be used instead of this object to specify the button text.
 
     Source: https://core.telegram.org/bots/api#keyboardbutton
     """
 
     text: str
-    """Text of the button. If none of the optional fields are used, it will be sent as a message when the button is pressed"""
+    """Text of the button. If none of the fields other than *text*, *icon_custom_emoji_id*, and *style* are used, it will be sent as a message when the button is pressed"""
+    icon_custom_emoji_id: str | None = None
+    """*Optional*. Unique identifier of the custom emoji shown before the text of the button. Can only be used by bots that purchased additional usernames on `Fragment <https://fragment.com>`_ or in the messages directly sent by the bot to private, group and supergroup chats if the owner of the bot has a Telegram Premium subscription."""
+    style: str | None = None
+    """*Optional*. Style of the button. Must be one of 'danger' (red), 'success' (green) or 'primary' (blue). If omitted, then an app-specific style is used."""
     request_users: KeyboardButtonRequestUsers | None = None
     """*Optional*. If specified, pressing the button will open a list of suitable users. Identifiers of selected users will be sent to the bot in a 'users_shared' service message. Available in private chats only."""
     request_chat: KeyboardButtonRequestChat | None = None
@@ -52,6 +55,8 @@ class KeyboardButton(MutableTelegramObject):
             __pydantic__self__,
             *,
             text: str,
+            icon_custom_emoji_id: str | None = None,
+            style: str | None = None,
             request_users: KeyboardButtonRequestUsers | None = None,
             request_chat: KeyboardButtonRequestChat | None = None,
             request_contact: bool | None = None,
@@ -67,6 +72,8 @@ class KeyboardButton(MutableTelegramObject):
 
             super().__init__(
                 text=text,
+                icon_custom_emoji_id=icon_custom_emoji_id,
+                style=style,
                 request_users=request_users,
                 request_chat=request_chat,
                 request_contact=request_contact,
