@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import TypeAlias
 
 from .inaccessible_message import InaccessibleMessage
 from .message import Message
 
-MaybeInaccessibleMessageUnion = Union[Message, InaccessibleMessage]
+MaybeInaccessibleMessageUnion: TypeAlias = Message | InaccessibleMessage
