@@ -1,6 +1,6 @@
-from typing import Union
+from typing import TypeAlias
 
 from .owned_gift_regular import OwnedGiftRegular
 from .owned_gift_unique import OwnedGiftUnique
 
-OwnedGiftUnion = Union[OwnedGiftRegular, OwnedGiftUnique]
+OwnedGiftUnion: TypeAlias = OwnedGiftRegular | OwnedGiftUnique
