@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import TypeAlias
 
 from .passport_element_error_data_field import PassportElementErrorDataField
 from .passport_element_error_file import PassportElementErrorFile
@@ -14,14 +14,14 @@ from .passport_element_error_translation_files import (
 )
 from .passport_element_error_unspecified import PassportElementErrorUnspecified
 
-PassportElementErrorUnion = Union[
-    PassportElementErrorDataField,
-    PassportElementErrorFrontSide,
-    PassportElementErrorReverseSide,
-    PassportElementErrorSelfie,
-    PassportElementErrorFile,
-    PassportElementErrorFiles,
-    PassportElementErrorTranslationFile,
-    PassportElementErrorTranslationFiles,
-    PassportElementErrorUnspecified,
-]
+PassportElementErrorUnion: TypeAlias = (
+    PassportElementErrorDataField
+    | PassportElementErrorFrontSide
+    | PassportElementErrorReverseSide
+    | PassportElementErrorSelfie
+    | PassportElementErrorFile
+    | PassportElementErrorFiles
+    | PassportElementErrorTranslationFile
+    | PassportElementErrorTranslationFiles
+    | PassportElementErrorUnspecified
+)
