@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from typing import Union
+from typing import TypeAlias
 
 from .reaction_type_custom_emoji import ReactionTypeCustomEmoji
 from .reaction_type_emoji import ReactionTypeEmoji
 from .reaction_type_paid import ReactionTypePaid
 
-ReactionTypeUnion = Union[ReactionTypeEmoji, ReactionTypeCustomEmoji, ReactionTypePaid]
+ReactionTypeUnion: TypeAlias = ReactionTypeEmoji | ReactionTypeCustomEmoji | ReactionTypePaid
